
local o = SimpleCoordinates;

-- Coordinates_t_Init: ()
-- Coordinates_OnEvent_VARIABLES_LOADED: ()
-- Coordinates_HandleSlashCmd_SetStatic: (args)
--
-- Coordinates_MobileLocsFrame_OnUpdate: (self, elapsed)
-- Coordinates_MobileLocsFrame_OnDragStop: (self)
-- Coordinates_WorldMapLocsFrame_OnUpdate: (self, elapsed)
--
-- Coordinates_SetStatic: (x, y)
-- Coordinates_ToggleUseMobile: (enable)

local SimpleCoordinates_MobileLocsFramePlayerLocText = nil;
local SimpleCoordinates_WorldMapLocsFrameCursorLocText = nil;
local SimpleCoordinates_WorldMapLocsFramePlayerLocText = nil;



function o.Coordinates_t_Init()
	o.Coordinates_t_Init = nil;
	
	SimpleCoordinates_WorldMapLocsFrameCursorLocText = _G.SimpleCoordinates_WorldMapLocsFrameCursorLocText;

	SimpleCoordinates_WorldMapLocsFramePlayerLocText = _G.SimpleCoordinates_WorldMapLocsFramePlayerLocText;
	
	local cmds = o.Localization.SLASH_COMMANDS;
	local slashInfo = {
		[cmds.S:match("^(%S+)")] = o.Coordinates_HandleSlashCmd_SetStatic;
		[cmds.STATIC:match("^(%S+)")] = o.Coordinates_HandleSlashCmd_SetStatic;
		[cmds.MOBILE:match("^(%S+)")] = o.Coordinates_ToggleUseMobile;
		[cmds.M:match("^(%S+)")] = o.Coordinates_ToggleUseMobile;
		[false] = {
			cmds.UNKNOWN;
			cmds.STATIC;
			cmds.S;
			cmds.MOBILE;
			cmds.M;
		};
	};
	NicheDevTools.RegisterSlashCommand("SimpleCoordinates", slashInfo, "/sc", "/simco");
	
	SimpleCoordinates_WorldMapLocsFrame:RegisterEvent("VARIABLES_LOADED");
	SimpleCoordinates_WorldMapLocsFrame:SetScript("OnEvent", o.Coordinates_OnEvent_VARIABLES_LOADED);
end



function o.Coordinates_OnEvent_VARIABLES_LOADED()
	o.Coordinates_OnEvent_VARIABLES_LOADED = nil;
	
	SimpleCoordinates_WorldMapLocsFrame:UnregisterEvent("VARIABLES_LOADED");
	SimpleCoordinates_WorldMapLocsFrame:SetScript("OnEvent", nil);
	
	if (SimpleCoordinates_NoMobileLocsFrame == nil) then
		local frame = o.GUI_t_CreateMobileFrame();
		SimpleCoordinates_MobileLocsFramePlayerLocText = _G.SimpleCoordinates_MobileLocsFramePlayerLocText;
		local pos = SimpleCoordinates_SavedMobileLocsFramePos;
		if (pos ~= nil) then
			local x, y = pos:match("^(%S+) (%S+)$");
			frame:ClearAllPoints();
			frame:SetPoint("CENTER", UIParent, "BOTTOMLEFT", tonumber(x), tonumber(y));
		end
	else
		o.GUI_t_CreateMobileFrame = nil;
		o.Coordinates_MobileLocsFrame_OnUpdate = nil;
		o.Coordinates_MobileLocsFrame_OnDragStop = nil;
		SimpleCoordinates_SavedMobileLocsFramePos = nil;
	end
end



function o.Coordinates_HandleSlashCmd_SetStatic(args)
	if (args ~= nil) then
		o.Coordinates_SetStatic(args:match("^([^, ]+)[, ] ?(%S+)$"));
	else
		o.Coordinates_SetStatic(nil, nil);
	end
end




do
	local SetMapToCurrentZone = SetMapToCurrentZone;
	local GetPlayerMapPosition = GetPlayerMapPosition;
	local l_elapsed = 2.0;
	
	function o.Coordinates_MobileLocsFrame_OnUpdate(self, elapsed)
		l_elapsed = (l_elapsed - elapsed);
		if (l_elapsed < 0.0) then
			l_elapsed = 2.0;
			
			SetMapToCurrentZone();
			local playerX, playerY = GetPlayerMapPosition("player");
			SimpleCoordinates_MobileLocsFramePlayerLocText:SetFormattedText("%d,%d", (playerX * 100), (playerY * 100));
		end
	end
end


function o.Coordinates_MobileLocsFrame_OnDragStop(self)
	self:StopMovingOrSizing();
	self:SetUserPlaced(false);
	local x, y = self:GetCenter();
	SimpleCoordinates_SavedMobileLocsFramePos = ("%d %d"):format(math.floor(x + 0.5), math.floor(y + 0.5));
end



do
	local WorldMapFrame = WorldMapFrame;
	local WorldMapButton = WorldMapButton;
	local GetCursorPosition = GetCursorPosition;
	local GetPlayerMapPosition = GetPlayerMapPosition;
	local loc_FORMAT_CURSOR = o.Localization.FORMAT_CURSOR;
	local loc_FORMAT_CURSOR_BLANK = o.Localization.FORMAT_CURSOR_BLANK;
	local loc_FORMAT_PLAYER = o.Localization.FORMAT_PLAYER;
	local l_elapsed = 0.25;
	
	function o.Coordinates_WorldMapLocsFrame_OnUpdate(self, elapsed)
		l_elapsed = (l_elapsed - elapsed);
		if (l_elapsed < 0.0) then
			l_elapsed = 0.25;
			
			local playerX, playerY = GetPlayerMapPosition("player");
			local cursorX, cursorY = GetCursorPosition();
			local scale = WorldMapDetailFrame:GetEffectiveScale();
			cursorX, cursorY = (cursorX / scale), (cursorY / scale);
			local width = WorldMapDetailFrame:GetWidth();
			local height = WorldMapDetailFrame:GetHeight();
			local centerX, centerY = WorldMapDetailFrame:GetCenter();
		if (100 * ((cursorX - (centerX - (width / 2.0))) / width)) < 0 or (100 * ((cursorX - (centerX - (width / 2.0))) / width)) > 100 or (100 * (((centerY + (height / 2.0) - cursorY) / height))) < 0 or (100 * (((centerY + (height / 2.0) - cursorY) / height))) > 100 then
			SimpleCoordinates_WorldMapLocsFrameCursorLocText:SetFormattedText(loc_FORMAT_CURSOR_BLANK);
			SimpleCoordinates_WorldMapLocsFramePlayerLocText:SetFormattedText(loc_FORMAT_PLAYER, (playerX * 100), (playerY * 100));
		else
			SimpleCoordinates_WorldMapLocsFrameCursorLocText:SetFormattedText(loc_FORMAT_CURSOR,
				(100 * ((cursorX - (centerX - (width / 2.0))) / width)),
				(100 * (((centerY + (height / 2.0) - cursorY) / height)))
			);

			
			SimpleCoordinates_WorldMapLocsFramePlayerLocText:SetFormattedText(loc_FORMAT_PLAYER, (playerX * 100), (playerY * 100));
				end
			end
		end
	end



do
	local loc_FORMAT_STATIC = o.Localization.FORMAT_STATIC;
	local loc_FORMAT_STATIC_BLANK = o.Localization.FORMAT_STATIC_BLANK;
	
	function o.Coordinates_SetStatic(x, y)
		if (x ~= nil and y ~= nil) then
			x, y = tonumber(x), tonumber(y);
			SimpleCoordinates_WorldMapLocsFrameStaticLocText:SetFormattedText(loc_FORMAT_STATIC, x, y);
			if (SimpleCoordinates_MobileLocsFrameStaticLocText ~= nil) then
				SimpleCoordinates_MobileLocsFrameStaticLocText:SetFormattedText("%d,%d", x, y);
			end
			local button = (SimpleCoordinates_StaticButton or o.GUI_t_CreateStaticButton());
			button:ClearAllPoints();
			button:SetPoint(
				"CENTER", WorldMapDetailFrame, "TOPLEFT",
				((x / 100) * WorldMapButton:GetWidth()),
				((-y / 100) * WorldMapButton:GetHeight())
			);
			button:Show();
		else
			SimpleCoordinates_WorldMapLocsFrameStaticLocText:SetText(loc_FORMAT_STATIC_BLANK);
			if (SimpleCoordinates_MobileLocsFrameStaticLocText ~= nil) then
				SimpleCoordinates_MobileLocsFrameStaticLocText:SetText("??,??");
			end
			if (SimpleCoordinates_StaticButton ~= nil) then
				SimpleCoordinates_StaticButton:Hide();
			end
		end
	end
end



function o.Coordinates_ToggleUseMobile(enable)
	if (enable == nil) then
		enable = (not not SimpleCoordinates_NoMobileLocsFrame);
	end
	enable = ((enable and true) or nil);
	
	SimpleCoordinates_NoMobileLocsFrame = ((enable == nil and true) or nil);
	if (SimpleCoordinates_MobileLocsFrame ~= nil) then
		if (enable == true) then
			SimpleCoordinates_MobileLocsFrame:Show();
		else
			SimpleCoordinates_MobileLocsFrame:Hide();
		end
	end
end
